@@ -116,6 +116,7 @@ sub poster_config { # posting to CoreSmokeDB
             ],
             'curl' => [
                 curlbin(),
+                curlargs(),
                 ua_timeout(),
             ],
         },
@@ -159,7 +160,7 @@ sub reposter_config {
         general_options => [
             adir(),
             commit_sha(),
-            jsnfile(),
+            jsonreport(),
             max_reports(),
             smokedb_url(),
         ],
@@ -418,6 +419,15 @@ sub commit_sha {
     );
 }
 
+sub curlargs {
+    return $opt->new(
+        name     => 'curlargs',
+        option   => '=s@',
+        default  => [ ],
+        helptext => "Extra switches to pass to curl (repeatable!)",
+    );
+}
+
 sub curlbin {
     return $opt->new(
         name       => 'curlbin',
@@ -666,6 +676,16 @@ sub jsnfile {
     );
 }
 
+sub jsonreport {
+    return $opt->new(
+        name     => 'jsonreport',
+        option   => '=s',
+        default  => undef,
+        helptext => "Name of json report file to re-post to the server"
+                  . " (Takes precedence over '--adir' and '--sha')",
+    );
+}
+
 sub killtime {
     return $opt->new(
         name => 'killtime',
@@ -911,7 +931,7 @@ sub poster {
         name       => 'poster',
         option     => '=s',
         allow      => [qw/HTTP::Tiny LWP::UserAgent curl/],
-        default    => 'LWP::UserAgent',
+        default    => 'HTTP::Tiny',
         helptext   => "The type of HTTP post system to use.",
         configtext => "Which HTTP client do you want to use?",
         configalt  => _helper('get_avail_posters'),
